@@ -21,6 +21,7 @@
 #include <stdlib.h>
 #include <time.h>
 #include <sys/types.h>
+#include <string.h>
 
 #include <lal/LALConstants.h>
 #include <lal/LALDatatypes.h>
@@ -82,21 +83,28 @@ const char * usage =
 "                             IMRPhenomB\n"
 "                             IMRPhenomC\n"
 "                             IMRPhenomD\n"
+"                             IMRPhenomHM\n"
 "                             IMRPhenomPv2\n"
+"                             IMRPhenomPv3\n"
+"                             IMRPhenomPv3HM\n"
 "                             EOBNRv2\n"
 "                             EOBNRv2HM\n"
 "                             SEOBNRv1\n"
 "                             SEOBNRv2\n"
 "                             SEOBNRv3\n"
 "                             SEOBNRv4\n"
+"                             SEOBNRv4HM\n"
+"                             SEOBNRv4P\n"
 "                             SEOBNRv2T\n"
 "                             SEOBNRv4T\n"
 "                             SpinTaylorT4\n"
-"                             SpinTaylorT2\n"
+"                             SpinTaylorT5\n"
 "                             PhenSpinTaylor\n"
 "                             PhenSpinTaylorRD\n"
 "                             SpinDominatedWf\n"
 "                             HGimri\n"
+"                             NRHybSur3dq8\n"
+"                             NR_hdf5\n"
 "                           Supported FD approximants:\n"
 "                             IMRPhenomA\n"
 "                             IMRPhenomB\n"
@@ -104,17 +112,22 @@ const char * usage =
 "                             IMRPhenomD\n"
 "                             IMRPhenomP\n"
 "                             IMRPhenomPv2\n"
+"                             IMRPhenomPv3\n"
+"                             IMRPhenomPv3HM\n"
 "                             EOBNRv2_ROM\n"
 "                             EOBNRv2HM_ROM\n"
 "                             SEOBNRv1_ROM_EffectiveSpin\n"
 "                             SEOBNRv1_ROM_DoubleSpin\n"
 "                             SEOBNRv2_ROM_EffectiveSpin\n"
 "                             SEOBNRv2_ROM_DoubleSpin\n"
+"                             SEOBNRv4_ROM\n"
+"                             SEOBNRv4HM_ROM\n"
 "                             TaylorF2\n"
+"                             TaylorF2Ecc\n"
 "                             SpinTaylorF2\n"
 "                             TaylorR2F4\n"
 "                             SpinTaylorT4Fourier\n"
-"                             SpinTaylorT2Fourier\n"
+"                             SpinTaylorT5Fourier\n"
 "                             TaylorF2RedSpin\n"
 "                             TaylorF2RedSpinTidal\n"
 "                           NOTE: Other approximants may be available if the\n"
@@ -141,6 +154,10 @@ const char * usage =
 "                           (~128-2560 for NS, 0 for BH) (default 0)\n"
 "--tidal-lambda2 L2         (tidal deformability of mass 2) / (mass of body 2)^5\n"
 "                           (~128-2560 for NS, 0 for BH) (default 0)\n"
+"--ecc_order eccO           PN order for eccentric correction term\n"
+"                           (-1 for maximum order) (default -1)\n"
+"--f_ecc f                  reference frequency for initial eccentricity\n"
+"                           (10Hz) (default 10)\n"
 "--tidal-lambda-octu1 L31         (octupolar tidal deformability of mass 1) / (mass of body 1)^7\n"
 "                           (0 for BH) (default 0)\n"
 "--tidal-lambda-octu2 L32         (octupolar tidal deformability of mass 2) / (mass of body 2)^7\n"
@@ -163,6 +180,7 @@ const char * usage =
 "--eccentricity ecc         Eccentricity (default 0)\n"
 "--mean-per-ano psi         Mean periastron anomaly in radians (default 0)\n"
 "--axis AXIS                for PhenSpin: 'View' (default), 'TotalJ', 'OrbitalL'\n"
+"--nr-file                  for NR_hdf5\n"
 "--nonGRpar NAME VALUE      add the nonGRparam with name 'NAME' and value 'VALUE'\n"
 "                           Supported names:\n"
 "                             NonGRPhi1\n"
@@ -182,6 +200,15 @@ const char * usage =
 "--higher-modes VALUE       specify l modes with value 'VALUE' (L2 or RESTRICTED is default)\n"
 "--outname FNAME            Output to file FNAME (default 'simulation.dat')\n"
 "--verbose                  If included, add verbose output\n"
+"--phenomXHMMband float     Threshold parameter for the Multibanding of IMRPhenomXHM. By default set to 10^-3. If set to 0 then do not use multibanding.\n"
+"--modesList string         List of modes to be used by the model, e.g. --modesList '2,2, 2,-2, 2,1, 2,-1'. \n"
+"                           To use all the modes available in the mode do not add --modesList. Do not use if you do not know which modes the model returns!\n"
+"--phenomXPHMMband float    Threshold parameter for the Multibanding of the Euler angles in IMRPhenomXPHM. \n"
+"                           Options and default values can be found in https://lscsoft.docs.ligo.org/lalsuite/lalsimulation/group___l_a_l_sim_i_m_r_phenom_x__c.html.\n"
+"--phenomXPHMUseModes int   Switch between the two polarization functions IMRPhenomXPHM and IMRPhenomXPHMFromModes.\n"
+"                           Options and default values can be found in https://lscsoft.docs.ligo.org/lalsuite/lalsimulation/group___l_a_l_sim_i_m_r_phenom_x__c.html.\n"
+"--phenomXPrecVersion int   Choose precessing version for the Euler angles.\n"
+"                           Options and default values can be found in https://lscsoft.docs.ligo.org/lalsuite/lalsimulation/group___l_a_l_sim_i_m_r_phenom_x__c.html.\n"
 ;
 
 /* Parse command line, sanity check arguments, and return a newly
@@ -221,9 +248,16 @@ static GSParams *parse_args(ssize_t argc, char **argv) {
     /* Note: given a LALDict, SEOBNRv2T/v4T will check wether other parameters ( TidalOctupolarLambda, TidalQuadrupolarFMode, TidalOctupolarFMode, dQuadMon) are present in the LALDict */
     /* If present, this value is looked up and used, if absent, the parameter is computed from quadrupolar lambda through universal relations */
     /* We therefore do not Insert default values for these parameters, they will be inserted in LALDict only if specified on the commandline */
-    strncpy(params->outname, "simulation.dat", 256); /* output to this file */
+    XLALSimInspiralWaveformParamsInsertPNEccentricityOrder(params->params, -1);
+    XLALSimInspiralWaveformParamsInsertEccentricityFreq(params->params, 10.0);
+    XLALSimInspiralWaveformParamsInsertTidalOctupolarLambda1(params->params, 0.);
+    XLALSimInspiralWaveformParamsInsertTidalOctupolarLambda2(params->params, 0.);
+    XLALSimInspiralWaveformParamsInsertTidalQuadrupolarFMode1(params->params, 0.);
+    XLALSimInspiralWaveformParamsInsertTidalQuadrupolarFMode2(params->params, 0.);
+    XLALSimInspiralWaveformParamsInsertTidalOctupolarFMode1(params->params, 0.);
+    XLALSimInspiralWaveformParamsInsertTidalOctupolarFMode2(params->params, 0.);
+    snprintf(params->outname, sizeof(params->outname), "simulation.dat"); /* output to this file */
     params->verbose = 0; /* No verbosity */
-
     /* consume command line */
     for (i = 1; i < argc; ++i) {
         if ((strcmp(argv[i], "-h") == 0) || (strcmp(argv[i], "--help") == 0)) {
@@ -284,6 +318,10 @@ static GSParams *parse_args(ssize_t argc, char **argv) {
 	    XLALSimInspiralWaveformParamsInsertTidalLambda1(params->params, atof(argv[++i]));
         } else if (strcmp(argv[i], "--tidal-lambda2") == 0) {
 	    XLALSimInspiralWaveformParamsInsertTidalLambda2(params->params, atof(argv[++i]));
+        } else if (strcmp(argv[i], "--ecc_order") == 0) {
+	    XLALSimInspiralWaveformParamsInsertPNEccentricityOrder(params->params, atoi(argv[++i]));
+        } else if (strcmp(argv[i], "--f_ecc") == 0) {
+	    XLALSimInspiralWaveformParamsInsertEccentricityFreq(params->params, atof(argv[++i]));
         } else if (strcmp(argv[i], "--tidal-lambda-octu1") == 0) {
         XLALSimInspiralWaveformParamsInsertTidalOctupolarLambda1(params->params, atof(argv[++i]));
         } else if (strcmp(argv[i], "--tidal-lambda-octu2") == 0) {
@@ -340,8 +378,32 @@ static GSParams *parse_args(ssize_t argc, char **argv) {
 	      XLALSimInspiralWaveformParamsInsertNonGRPhi1(params->params,atof(argv[++i]));
 	    }
         } else if (strcmp(argv[i], "--outname") == 0) {
-            strncpy(params->outname, argv[++i], 256);
-        } else {
+            snprintf(params->outname, sizeof(params->outname), "%s", argv[++i]);
+        } else if (strcmp(argv[i], "--nr-file") == 0) {
+	  XLALSimInspiralWaveformParamsInsertNumRelData(params->params, argv[++i]);
+        } else if (strcmp(argv[i], "--modesList") == 0) {
+            char numbers_str[50], *currnum;
+            strncpy(numbers_str, argv[++i], strlen(numbers_str)-1);
+            int numbers[25], iii = 0;
+            while ((currnum = strtok(iii ? NULL : numbers_str, ",")) != NULL){
+              numbers[iii++] = atoi(currnum);
+            }
+            LALValue *ModeArray = XLALSimInspiralCreateModeArray();
+            for (int ii=0; ii<iii; ii+=2){
+               XLALSimInspiralModeArrayActivateMode(ModeArray, numbers[ii], numbers[ii+1]);
+               XLALSimInspiralWaveformParamsInsertModeArray(params->params, ModeArray);
+             }
+             XLALDestroyValue(ModeArray);
+
+        }else if(strcmp(argv[i], "--phenomXHMMband") == 0){
+            XLALSimInspiralWaveformParamsInsertPhenomXHMThresholdMband(params->params, atof(argv[++i]));
+        }else if(strcmp(argv[i], "--phenomXPHMMband") == 0){
+            XLALSimInspiralWaveformParamsInsertPhenomXPHMThresholdMband(params->params, atof(argv[++i]));
+        }else if(strcmp(argv[i], "--phenomXPHMUseModes") == 0){
+            XLALSimInspiralWaveformParamsInsertPhenomXPHMThresholdMband(params->params, atoi(argv[++i]));
+        }else if(strcmp(argv[i], "--phenomXPrecVersion") == 0){
+            XLALSimInspiralWaveformParamsInsertPhenomXPrecVersion(params->params, atoi(argv[++i]));
+        }else {
             XLALPrintError("Error: invalid option: %s\n", argv[i]);
             goto fail;
         }
@@ -422,7 +484,7 @@ static int dump_FD2(FILE *f, COMPLEX16FrequencySeries *hptilde,
 
     fprintf(f, "# f amp_+ phase_+ amp_x phase_x\n");
     for (i=0; i < hptilde->data->length; i++)
-        fprintf(f, "%.16e %.16e %.16e %.16e %.16e\n",
+        fprintf(f, "%25.16e %25.16e %25.16e %25.16e %25.16e\n",
                 hptilde->f0 + i * hptilde->deltaF,
                 amp1[i], phaseUW1[i], amp2[i], phaseUW2[i]);
     return 0;
@@ -441,7 +503,7 @@ static int dump_TD(FILE *f, REAL8TimeSeries *hplus, REAL8TimeSeries *hcross) {
 
     fprintf(f, "# t hplus hcross\n");
     for (i=0; i < hplus->data->length; i++)
-        fprintf(f, "%.16e %.16e %.16e\n", t0 + i * hplus->deltaT,
+        fprintf(f, "%25.16e %25.16e %25.16e\n", t0 + i * hplus->deltaT,
                 hplus->data->data[i], hcross->data->data[i]);
     return 0;
 }
@@ -471,7 +533,7 @@ static int dump_TD2(FILE *f, REAL8TimeSeries *hplus, REAL8TimeSeries *hcross) {
 
     fprintf(f, "# t amp phase\n");
     for (i=0; i < hplus->data->length; i++)
-        fprintf(f, "%.16e %.16e %.16e\n", t0 + i * hplus->deltaT,
+        fprintf(f, "%25.16e %25.16e %25.16e\n", t0 + i * hplus->deltaT,
                 amp[i], phaseUW[i]);
     return 0;
 }
