@@ -40,7 +40,7 @@
 #include <gsl/gsl_spline.h>
 #include <gsl/gsl_math.h>
 
-#include "../src/LALSimIMRPhenomP.c" /* Include source directly so we can carry out unit tests for internal functions */
+#include <LALSimIMRPhenomP.c> /* Include source directly so we can carry out unit tests for internal functions */
 
 #define MYUNUSED(expr) do { (void)(expr); } while (0)
 
@@ -418,6 +418,7 @@ static void Test_XLALSimIMRPhenomP(void) {
   REAL8 f_min = 20;
   REAL8 f_ref = f_min;
   IMRPhenomP_version_type version = IMRPhenomPv2_V;
+  NRTidal_version_type NRTv = NoNRT_V;
 
   XLALSimIMRPhenomPCalculateModelParametersOld(
       &chi1_l,            /**< Output: aligned spin on companion 1 */
@@ -463,6 +464,7 @@ static void Test_XLALSimIMRPhenomP(void) {
     f_max,                    /**< End frequency; 0 defaults to ringdown cutoff freq */
     f_ref,                    /**< Reference frequency */
     version,
+    NRTv,
     NULL);                   /**<linked list containing the extra testing GR parameters */
 
   dump_file("PhenomP_Test1.dat", hptilde, hctilde, m1+m2);
@@ -472,8 +474,8 @@ static void Test_XLALSimIMRPhenomP(void) {
   prC("hp", hp);
   prC("hc", hc);
 
-  COMPLEX16 hp_expected = -5.17559e-23 + I * 2.60627e-23;
-  COMPLEX16 hc_expected =  2.60624e-23 + I * 5.17509e-23;
+  COMPLEX16 hp_expected = -5.17642e-23 + I * 2.60463e-23;
+  COMPLEX16 hc_expected =  2.6046e-23 + I * 5.17592e-23;
   const REAL8 eps = 1e-5;
 
   assert(
@@ -641,6 +643,7 @@ static void Test_XLALSimIMRPhenomP_f_ref(void) {
   REAL8 f_min = 20;
   REAL8 f_ref = f_min;
   IMRPhenomP_version_type version = IMRPhenomPv2_V;
+  NRTidal_version_type NRTv = NoNRT_V;
 
   XLALSimIMRPhenomPCalculateModelParametersOld(
       &chi1_l,            /**< Output: aligned spin on companion 1 */
@@ -686,6 +689,7 @@ static void Test_XLALSimIMRPhenomP_f_ref(void) {
     f_max,                    /**< End frequency; 0 defaults to ringdown cutoff freq */
     f_ref,                    /**< Reference frequency */
     version,
+    NRTv,
     NULL);
 
   dump_file("PhenomP_Test_f_ref1.dat", hptilde, hctilde, m1+m2);
@@ -739,6 +743,7 @@ static void Test_XLALSimIMRPhenomP_f_ref(void) {
     f_max,                    /**< End frequency; 0 defaults to ringdown cutoff freq */
     f_ref,                    /**< Reference frequency */
     version,
+    NRTv,
     NULL);
 
 
